@@ -103,6 +103,51 @@ namespace Imendio.Blam {
 	    return false;
 	}
 
+	public bool IdleScrollCb ()
+	{
+	    TreeIter iter;
+	    TreeIter lastIter = TreeIter.Zero;
+	    TreePath path = null;
+
+	    if (!this.Model.GetIterFirst (out iter)) {
+		// No items 
+		return false;
+	    }
+
+	    bool reverse = Conf.Get (Preference.REVERSE_ENTRIES, false);
+	    
+	    do {
+		Item item = (Item) this.Model.GetValue (iter, 0);
+		if (item.Unread) {
+		    if (((ListStore)this.Model).IterIsValid (lastIter)) {
+			path = this.Model.GetPath (lastIter);
+		    } else {
+			path = this.Model.GetPath (iter);
+		    }
+		    break;
+		} 
+		lastIter = iter.Copy ();
+	    } while (this.Model.IterNext (ref iter));
+	   
+	    if (path == null) { 
+		if (reverse) {
+		    path = TreePath.NewFirst ();
+		} else {
+		    if (!((ListStore)this.Model).IterIsValid (lastIter)) {
+			return false;
+		    }
+		
+		    path = this.Model.GetPath (lastIter);
+		}
+	    }
+
+	    if (path != null) {
+		ScrollToCell (path, titleColumn, true, 0, 0);
+	    }
+	    
+	    return false;
+	}
+
 	public void UpdateList ()
 	{
 	    ((ListStore)this.Model).Clear();
@@ -114,6 +159,8 @@ namespace Imendio.Blam {
 	    foreach (Imendio.Blam.Item item in this.channel.Items) {
 		((ListStore)this.Model).AppendValues (item);
 	    }
+
+	    GLib.Timeout.Add (100, new GLib.TimeoutHandler (IdleScrollCb));
 	}
 
 	public void Update (Item item)
@@ -155,6 +202,7 @@ namespace Imendio.Blam {
 	    }
 	}
 
+	private SortFunc itemSortFunc;
 	private int ItemSortFunc(IntPtr a, IntPtr b)
 	{
 	    int retVal;
@@ -174,7 +222,7 @@ namespace Imendio.Blam {
 	    case Gdk.Key.space:
 	    case Gdk.Key.Page_Up:
 	    case Gdk.Key.Page_Down:
-		itemView.ProcessEvent (kEvent);
+		itemView.Widget.ProcessEvent (kEvent);
 		return false;
 		// return itemView.OnKeyPressEvent (kEvent);
 	    default:
@@ -218,8 +266,9 @@ namespace Imendio.Blam {
 	{
 	    bool reverseEntries;
 
+	    itemSortFunc = new SortFunc (ItemSortFunc);
 	    Utils.TreeSetDefaultSortFunc(this.Model.Handle,
-					 new SortFunc(ItemSortFunc));
+					 itemSortFunc);
 	    
 	    reverseEntries = Conf.Get (Preference.REVERSE_ENTRIES, false);
 	    SetSortOrder (reverseEntries);
